"use client"
import { FormField, FormItem, FormLabel, FormControl } from "@/components/ui/form"
import { Popover, PopoverContent, PopoverPortal, PopoverTrigger } from "@radix-ui/react-popover"
import { Checkbox } from "@radix-ui/react-checkbox"
import { Button } from "@/components/ui/button"
import { cn } from "@/lib/utils"
export default function GenrePicker({ genres, value, form, ref }) {

	return (
		<>
			<FormItem className="flex flex-col">
				<Popover>
					<PopoverPortal container={ref}>
						<PopoverTrigger asChild>
							<Button
								variant={"outline"}
								className={cn(
									"min-w-fit max-w-screen-sm w-fit pl-3 text-left font-normal",
									!value && "text-muted-foreground"
								)}
							>
								{value.length !== 0 ? (
									value.map((e, i) => genres.find(f => e === f.id).name +
										(i < value.length - 1 ? ', ' : ''))
								) : (
									<FormLabel>Genres</FormLabel>
								)}
							</Button>
						</PopoverTrigger>
						<PopoverContent>
							{genres.map((item) => (
								<FormField
									key={item.id}
									control={form.control}
									name="genres"
									render={({ field }) => {
										return (
											<FormItem
												key={item.id}
												className="flex flex-row items-start space-x-3 space-y-0"
											>
												<FormControl>
													<Checkbox
														checked={field.value?.includes(item.id)}
														onCheckedChange={(checked) => {
															return checked
																? field.onChange([...field.value, item.id])
																: field.onChange(
																	field.value?.filter(
																		(value) => value !== item.id
																	)
																)
														}}
													/>
												</FormControl>
												<FormLabel className="text-sm font-normal">
													{item.name}
												</FormLabel>
											</FormItem>
										)
									}}
								/>
							))}
						</PopoverContent>
					</PopoverPortal>
				</Popover>
			</FormItem>

		</>

	)
}
